Skip to main content

SSHUP

A Simple SSH Manager

Usage:

Commands:
  sshup             Start the interactive menu
  sshup --edit      Open the config file in your default editor
  sshup --list      List configured servers
  sshup --cmd       Run a command on the host
  sshup --version   Get sshup version number
  sshup --help      Show this help message

Flags:
  -e, --edit    Edit the config file
  -l, --list    List all servers
  -c, --cmd     Run command on host
  -v, --version Show version number
  -h, --help    Show this help message

Config:

First run will create a default config file in the below path, make sure to edit with the correct credentials:

~/.sshup/config.yaml

Compatibility:

  • OS: Windows 11, macOS, Linux, FreeBSD, OpenBSD
  • Shell: Bash, zsh, sh
  • Python: 3.9, 3.10, 3.11, 3.12

Dev Setup

Install from local repo:

sudo pip3 install . --break-system-packages

Features:

  • Interactive TUI
  • Cross Platform (Windows, Linux, Mac, BSD)
  • YAML Based Config
  • .ssh/config Config Editing
  • Command Exection on Host
  • Command Execution on Multiple Hosts Simultaneously
  • Search & Filtering
  • Grouping
  • Autocompletion
  • History
  • Key Management

ToDo:

Metadata

Release files for sshup 0.0.9

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for sshup 0.0.9
File Size Uploaded
sshup-0.0.9.tar.gz 5.0 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for sshup 0.0.9
File Interpreter ABI Platform
sshup-0.0.9-py3-none-any.whl Python 3 none any Details

Total release size: 10.3 kB

Release files / sshup-0.0.9.tar.gz

Download URL sshup-0.0.9.tar.gz
Size 5.0 kB
Tags Source
SHA-256 checksum
How to use checksums
e0c04caa84a20950cb1dd2013f61f7c6d4ac860e5eafe06800ac9f3a552cd9c1
BLAKE2b-256 checksum
How to use checksums
ed1b57c8f42d29d5faae794d8ffea9da32210e289e50e3371ae148e912eb151f
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/6.1.0 CPython/3.13.3

Release files / sshup-0.0.9-py3-none-any.whl

Download URL sshup-0.0.9-py3-none-any.whl
Size 5.3 kB
Tags Python 3
SHA-256 checksum
How to use checksums
8048b3fcb393627df8f1867aece5e939194b54c8a8b3e950af0d5307e22f2413
BLAKE2b-256 checksum
How to use checksums
11aac39e39cd76556eace058ed00db996a5183005e6cf49dec8a818bea04f52a
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/6.1.0 CPython/3.13.3

Release history Release notifications | RSS feed

This release

0.0.9 This release

2 release files

0.0.8

2 release files

0.0.7

2 release files

0.0.6

2 release files

0.0.5

2 release files

0.0.4

2 release files

0.0.3

2 release files

0.0.2

2 release files

0.0.1

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page